<?php

namespace ConsentMagicPro;

if ( !defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class CS_AdminPageMain extends CS_AdminPage implements CS_Page {

	/**
	 * Admin page main
	 * @return void
	 */
	public function renderPage() {

		$this->dbCronHandle();

		$this->manageCSPermissions();

		//check load translations for current plugin version
		if ( ConsentMagic()->getOption( 'cs_check_translations' ) != CMPRO_LATEST_VERSION_NUMBER ) {
			$this->admin->loadTranslations( false );
			$this->admin->loadCategoriesTranslations( false );
		}

		// Get options:
		$design_options = ConsentMagic()->getCSOptionsDesign();

		if ( isset( $_GET[ 'primary_rule_id' ] ) ) {
			require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/primary-rules/edit-primary-rule-html.php';
		} else if ( isset( $_GET[ 'new_rule' ] ) ) {
			require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/primary-rules/add-new-primary-rule-html.php';
		} else if ( isset( $_GET[ 'new_script' ] ) || isset( $_GET[ 'script_id' ] ) ) {
			if ( isset( $_GET[ 'script_id' ] ) ) {
				$id = sanitize_text_field( $_GET[ 'script_id' ] );
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/scripts/edit-script-html.php';
			} else {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/scripts/add-script-html.php';
			}
		} else if ( isset( $_GET[ 'design_template' ] ) ) {
			$this->designTemplatesHandle();
		} elseif ( isset( $_POST[ '_wpnonce' ] ) && wp_verify_nonce( $_POST[ '_wpnonce' ], 'cs-update-' . CMPRO_SETTINGS_FIELD ) ) {

			// Check if form has been set:
			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_admin_settings_form' ) {

				$this->updateCronHandle();

				if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_check_flow' ] ) ) {

					if ( isset( $_POST[ 'cs_active_rule_id_first' ] ) ) {
						$this->change_rule_order_admin( (int) sanitize_text_field( $_POST[ 'cs_active_rule_id_first' ] ) );
					}
					$user_id = get_current_user_id();
					add_user_meta( $user_id, 'cs_notice_dismissed', 'true', true );

					if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_block_googlefonts_enabled' ] ) ) {
						$term = get_term_by( 'slug', 'googlefonts', 'cs-cookies-category' );
						if ( $term ) {
							$val = !(bool) sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_block_googlefonts_enabled' ] );
							update_term_meta( $term->term_id, 'cs_ignore_this_category', $val );
						}
					}
				}

				$this->updateOptionsHandle();

				foreach ( $design_options as $key => $value ) {
					if ( isset( $_POST[ 'cs_d' ][ $this->plugin_name ][ $key ] ) ) {
						ConsentMagic()->updateOptionsDesign( sanitize_text_field( $_POST[ 'cs_d' ][ $this->plugin_name ][ $key ] ) );
					}
				}

				if ( isset( $_POST[ 'cs_post_name' ] ) && isset( $_POST[ 'cs_rule_id' ] ) ) {
					$rule_post                 = array();
					$rule_post[ 'ID' ]         = isset( $_POST[ 'cs_rule_id' ] ) ? sanitize_text_field( $_POST[ 'cs_rule_id' ] ) : null;
					$rule_post[ 'post_title' ] = isset( $_POST[ 'cs_post_name' ] ) ? sanitize_text_field( $_POST[ 'cs_post_name' ] ) : null;
					wp_update_post( wp_slash( $rule_post ) );
				}

				if ( isset( $_POST[ 'cs_gdpr_rule' ] ) ) {
					$id = get_post_id_by_slug( 'cs_gdpr_rule' );
					update_post_meta( $id, '_cs_enable_rule', sanitize_text_field( $_POST[ 'cs_gdpr_rule' ] ) );
				}
				if ( isset( $_POST[ 'cs_ldu_rule' ] ) ) {
					$id = get_post_id_by_slug( 'cs_ldu_rule' );
					update_post_meta( $id, '_cs_enable_rule', sanitize_text_field( $_POST[ 'cs_ldu_rule' ] ) );
				}
				if ( isset( $_POST[ 'cs_rest_of_world_rule' ] ) ) {
					$id = get_post_id_by_slug( 'cs_rest_of_world_rule' );
					update_post_meta( $id, '_cs_enable_rule', sanitize_text_field( $_POST[ 'cs_rest_of_world_rule' ] ) );
				}
				if ( isset( $_POST[ 'cs_iab_rule' ] ) ) {
					$id = get_post_id_by_slug( 'cs_iab_rule' );
					update_post_meta( $id, '_cs_enable_rule', sanitize_text_field( $_POST[ 'cs_iab_rule' ] ) );
				}

				if ( isset( $_POST[ 'cs' ][ 'custom_enable' ] ) && !empty( $_POST[ 'cs' ][ 'custom_enable' ] ) ) {
					foreach ( $_POST[ 'cs' ][ 'custom_enable' ] as $key => $val ) {
						$data_arr = array(
							'cookie_enabled' => sanitize_text_field( $val ),
						);
						update_scan_cookie_data( sanitize_text_field( $key ), $data_arr );
					}
				}

				if ( isset( $_POST[ 'cs' ][ 'custom_cookie_cat' ] ) && !empty( $_POST[ 'cs' ][ 'custom_cookie_cat' ] ) ) {
					foreach ( $_POST[ 'cs' ][ 'custom_cookie_cat' ] as $key => $val ) {
						$category_id = get_term_by( 'slug', sanitize_text_field( $val ), 'cs-cookies-category' );
						$data_arr    = array(
							'category'    => sanitize_text_field( $val ),
							'category_id' => $category_id->term_id
						);
						update_scan_cookie_data( sanitize_text_field( $key ), $data_arr );
					}
				}

				$unassigned = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );

				foreach ( $_POST as $item_name => $val ) {
					$item_name = sanitize_text_field( $item_name );
					$val       = sanitize_text_field( $val );

					if ( get_option( $item_name ) !== false ) {
						update_option( $item_name, $val );
					}
					if ( stripos( $item_name, '_cookie_cat' ) ) {
						$cookie_id = preg_replace( "/[^0-9]/", '', $item_name );
						wp_set_object_terms( $cookie_id, $val, 'cs-cookies-category' );
					}

					if ( stripos( $item_name, '_script_cat' ) ) {
						$cookie_id = preg_replace( "/[^0-9]/", '', $item_name );
						wp_set_object_terms( $cookie_id, $val, 'cs-cookies-category' );
					}

					if ( stripos( $item_name, 'category_' . $unassigned->term_id ) ) {
						$cookie_id = preg_replace( "/[^0-9]/", '', $item_name );
						if ( $cookie_id == $unassigned->term_id ) {
							update_term_meta( $cookie_id, 'cs_ignore_this_category', $val );
						}
					}

					if ( stripos( $item_name, '_script_enable' ) ) {
						update_option( $item_name, $val );
					}
					if ( stripos( $item_name, '_cookie_enable' ) ) {
						update_option( $item_name, $val );
					}
				}

				$this->updateRuleIdHandle();

				$this->renderSuccessMessage();
			}

			$this->addDesignTemplateHandle();
			$this->updateDesignTemplateHandle();
			$this->deleteDesignTemplateHandle();

			$this->addNewCookieCategoryHandle();
			$this->updateCookieCategoryHandle();
			$this->deleteCookieCategoryHandle();

			$this->addRuleHandle();

			$this->addScriptHandle();
			$this->updateScriptHandle();

			$this->addCookieHandle();
			$this->updateCookieHandle();

			if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'btn_restore_adjust' ) {
				delete_option( CMPRO_SETTINGS_DESIGN_FIELD );
			}

			if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'delete_custom_post' ) {

				if ( isset( $_POST[ 'post_id' ] ) ) {
					$post_id  = isset( $_POST[ 'post_id' ] ) ? sanitize_text_field( $_POST[ 'post_id' ] ) : null;
					$data_cat = isset( $_POST[ 'data_cat' ] ) ? sanitize_text_field( $_POST[ 'data_cat' ] ) : null;
					wp_delete_post( $post_id, true );
					delete_option( 'cs_' . $data_cat . '_' . $post_id . '_cookie_enable' );
					delete_option( 'cs_' . $post_id . '_cookie_cat' );
					delete_option( 'cs_' . $data_cat . '_' . $post_id . '_script_enable' );
					delete_option( 'cs_' . $post_id . '_script_cat' );
				}
			}
		}

		$this->checkFlow( 'admin/general/html-wrapper-main.php' );

	}

	/**
	 * @return void
	 */
	private function dbCronHandle() {
		if ( ConsentMagic()->getOption( 'cs_geolocation' ) && ConsentMagic()->getOption( 'cs_geo_activated' ) && ConsentMagic()->getOption( 'cs_often_update' ) != 'never' ) {
			db_cron_update();
		} else {
			db_cron_deactivate();
		}
	}

	private function designTemplatesHandle() {
		$border_style = ConsentMagic()->getOption( 'cs_border_style_list' );

		$sizes_array = get_intermediate_image_sizes();

		$img_sizes_array = array();

		foreach ( $sizes_array as $key => $val ) {
			$img_sizes_array[ $val ] = $val;
		}

		if ( $_GET[ 'design_template' ] == 'add' ) {
			require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/add-design-template-html.php';
		} else {
			$id = isset( $_GET[ 'template_id' ] ) ? sanitize_text_field( $_GET[ 'template_id' ] ) : '';
			require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/edit-design-template-html.php';
		}
	}

	public function change_rule_order_admin( $rule_id ) {
		$args_posts = array(
			'post_type'      => CMPRO_POST_TYPE,
			'post_status'    => 'publish',
			'include'        => array( $rule_id ),
			'posts_per_page' => 1,
		);
		$rule_first = get_posts( $args_posts );

		$args_posts = array(
			'post_type'      => CMPRO_POST_TYPE,
			'post_status'    => 'publish',
			'posts_per_page' => -1,
			'order'          => 'ASC',
			'exclude'        => $rule_id

		);
		$rule_other = get_posts( $args_posts );

		if ( $rule_first != false && !empty( $rule_first ) ) {
			$counter = 0;
			update_post_meta( $rule_first[ 0 ]->ID, '_cs_order', $counter );

			$counter++;
			if ( $rule_other != false && !empty( $rule_other ) ) {
				foreach ( $rule_other as $rule ) {
					update_post_meta( $rule->ID, '_cs_order', $counter );
					$counter++;
				}
			}
		}
	}

	private function updateCronHandle() {
		$cs_auto_scan_interval = ConsentMagic()->getOption( 'cs_auto_scan_interval' );
		if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_auto_scan_interval' ] ) && ( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_auto_scan_interval' ] !== $cs_auto_scan_interval ) ) {
			if ( wp_next_scheduled( 'cs_cron_bulck_scan_hook' ) ) {
				wp_clear_scheduled_hook( 'cs_cron_bulck_scan_hook' );
				if ( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_auto_scan_interval' ] == "once_a_week" ) {
					wp_schedule_event( time(), 'weekly', 'cs_cron_bulck_scan_hook' );
				} else if ( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_auto_scan_interval' ] == "once_a_month" ) {
					wp_schedule_event( time(), 'monthly', 'cs_cron_bulck_scan_hook' );
				} else {
					if ( wp_next_scheduled( 'cs_cron_bulck_scan_hook' ) ) {
						wp_clear_scheduled_hook( 'cs_cron_bulck_scan_hook' );
					}
				}
			}
		}
	}

	private function updateOptionsHandle() {
		$the_options = ConsentMagic()->getCSOptions();

		foreach ( $the_options as $key => $value ) {
			if ( isset( $_POST[ 'cs' ][ $this->plugin_name ] ) && is_array( $_POST[ 'cs' ][ $this->plugin_name ] ) ) {

				$key_langs = array();
				$all_langs = get_language_list();
				$lang_save = false;
				foreach ( $_POST[ 'cs' ][ $this->plugin_name ] as $post_key => $post_val ) {
					$post_key = sanitize_text_field( $post_key );
					$post_val = sanitize_text_field( $post_val );
					if ( $post_key != $key . '_0' && !empty( $post_val ) ) {
						if ( strripos( $post_key, $key ) !== false ) {
							$lang = str_replace( $key . '_', '', $post_key );
							if ( $lang != $post_key && array_key_exists( $lang, $all_langs ) ) {

								if ( in_array( $key, get_text_editor_fields() ) ) {
									ConsentMagic()->updateLangOptions( array( $key => wp_kses_post( wp_unslash( $_POST[ 'cs' ][ $this->plugin_name ][ $post_key ] ) ) ), $lang );
								} else {
									ConsentMagic()->updateLangOptions( array( $key => sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $post_key ] ) ), $lang );
								}

								array_push( $key_langs, $lang );
								$lang_save = true;
							}
						}
					}
				}

				if ( $lang_save && isset( $_POST[ 'cs' ][ $this->plugin_name ][ "{$key}_language_control" ] ) && $_POST[ 'cs' ][ $this->plugin_name ][ "{$key}_language_control" ] != 0 ) {
					ConsentMagic()->updateOptions( array( $key . '_lang' => $key_langs ) );
					ConsentMagic()->update_language_availability( $key_langs );
				}
			}

			if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) {
				switch ( $key ) {
					case 'cs_auto_scan_email':
						$email = sanitize_email( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] );
						if ( !empty( $email ) ) {
							ConsentMagic()->updateOptions( array( $key => $email ) );
						}
						break;
					default:
						ConsentMagic()->updateOptions( array( $key => sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) );
						break;
				}

				//Save pys cookie category to scan result table
				if ( $key == 'cs_block_pys_scripts_cat' ) {
					$scanner = new CS_Scanner_Module();
					$scanner->update_scan_pys_category( sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) );
				}
			}


			if ( isset( $_POST[ '_cs_top_push' ] ) ) {
				$_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] = sanitize_text_field( $_POST[ '_cs_top_push' ] );
				ConsentMagic()->updateOptions( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] ) ? sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] ) : '' );
			}
		}
	}

	private function updateRuleIdHandle() {
		if ( isset( $_POST[ 'cs_rule_id' ] ) ) {

			$options   = get_lang_meta_list();
			$all_langs = get_language_list();

			foreach ( $options as $option ) {
				$key_langs = array();
				foreach ( $_POST as $item_name => $val ) {
					$item_name = sanitize_text_field( $item_name );
					if ( strripos( $item_name, $option ) !== false ) {
						$lang = str_replace( $option . '_', '', $item_name );

						if ( $lang != $option && array_key_exists( $lang, $all_langs ) ) {
							array_push( $key_langs, $lang );
						}
					}
				}
				update_post_meta( sanitize_text_field( $_POST[ 'cs_rule_id' ] ), $option . '_lang', $key_langs );
				ConsentMagic()->update_language_availability( $key_langs );
			}

			$rule_id = sanitize_text_field( $_POST[ 'cs_rule_id' ] );

			foreach ( $_POST as $item_name => $val ) {
				if ( gettype( $val ) === 'string' ) {
					update_post_meta( $rule_id, sanitize_text_field( $item_name ), wp_kses_post( wp_unslash( $val ) ) );
				}
			}

			$this->admin->change_active_rule();
		}
	}

	private function updateDesignTemplateHandle() {
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_design_template_form' ) {

			$post_data = array();
			array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function( &$value, $key ) use ( &$post_data ) {
				$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
			} );

			$post_id = $post_data[ 'cs_template_id' ];

			$template_data = array(
				'ID'         => $post_id,
				'post_title' => $post_data[ 'cs_post_name' ],
				'meta_input' => array(
					'cs_backend_color'                    => $post_data[ 'cs_backend_color' ],
					'cs_border_style'                     => $post_data[ 'cs_border_style' ],
					'cs_border_weight'                    => $post_data[ 'cs_border_weight' ],
					'cs_border_color'                     => $post_data[ 'cs_border_color' ],
					'cs_text_block_bg'                    => $post_data[ 'cs_text_block_bg' ],
					'cs_text_color'                       => $post_data[ 'cs_text_color' ],
					'cs_links_color'                      => $post_data[ 'cs_links_color' ],
					'cs_titles_text_color'                => $post_data[ 'cs_titles_text_color' ],
					'cs_subtitles_text_color'             => $post_data[ 'cs_subtitles_text_color' ],
					'cs_accept_all_buttons_bg'            => $post_data[ 'cs_accept_all_buttons_bg' ],
					'cs_accept_all_buttons_text_color'    => $post_data[ 'cs_accept_all_buttons_text_color' ],
					'cs_custom_button_buttons_bg'         => $post_data[ 'cs_custom_button_buttons_bg' ],
					'cs_custom_button_buttons_text_color' => $post_data[ 'cs_custom_button_buttons_text_color' ],
					'cs_deny_all_buttons_bg'              => $post_data[ 'cs_deny_all_buttons_bg' ],
					'cs_deny_all_buttons_text_color'      => $post_data[ 'cs_deny_all_buttons_text_color' ],
					'cs_options_buttons_text_color'       => $post_data[ 'cs_options_buttons_text_color' ],
					'cs_options_buttons_bg'               => $post_data[ 'cs_options_buttons_bg' ],
					'cs_confirm_buttons_bg'               => $post_data[ 'cs_confirm_buttons_bg' ],
					'cs_confirm_buttons_text_color'       => $post_data[ 'cs_confirm_buttons_text_color' ],
					'cs_sticky_bg'                        => $post_data[ 'cs_sticky_bg' ],
					'cs_sticky_link_color'                => $post_data[ 'cs_sticky_link_color' ],
					'cs_logo'                             => $post_data[ 'cs_logo' ],
					'cs_position_vertical_list'           => $post_data[ 'cs_position_vertical_list' ],
					'cs_position_horizontal_list'         => $post_data[ 'cs_position_horizontal_list' ],
					'cs_logo_size'                        => $post_data[ 'cs_logo_size' ],
					'cs_cat_color'                        => $post_data[ 'cs_cat_color' ],
					'cs_active_toggle_color'              => $post_data[ 'cs_active_toggle_color' ],
					'cs_active_toggle_text_color'         => $post_data[ 'cs_active_toggle_text_color' ],
					'cs_main_template'                    => '',
					'cs_shortcodes_text_color'            => $post_data[ 'cs_shortcodes_text_color' ],
				)
			);

			wp_update_post( $template_data );

			$this->renderSuccessMessage();
		}
	}

	private function addDesignTemplateHandle() {
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'add_design_template_form' ) {

			$post_data = array();
			array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function( &$value, $key ) use ( &$post_data ) {
				$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
			} );

			$template_data = array(
				'post_type'   => CMPRO_TEMPLATE_POST_TYPE,
				'post_title'  => $post_data[ 'cs_default_template_name' ],
				'post_status' => 'publish',
				'ping_status' => 'closed',
				'post_author' => 1,
				'meta_input'  => array(
					'cs_backend_color'                    => $post_data[ 'cs_backend_color' ],
					'cs_border_style'                     => $post_data[ 'cs_border_style' ],
					'cs_border_weight'                    => $post_data[ 'cs_border_weight' ],
					'cs_border_color'                     => $post_data[ 'cs_border_color' ],
					'cs_text_block_bg'                    => $post_data[ 'cs_text_block_bg' ],
					'cs_text_color'                       => $post_data[ 'cs_text_color' ],
					'cs_links_color'                      => $post_data[ 'cs_links_color' ],
					'cs_titles_text_color'                => $post_data[ 'cs_titles_text_color' ],
					'cs_subtitles_text_color'             => $post_data[ 'cs_subtitles_text_color' ],
					'cs_accept_all_buttons_bg'            => $post_data[ 'cs_accept_all_buttons_bg' ],
					'cs_accept_all_buttons_text_color'    => $post_data[ 'cs_accept_all_buttons_text_color' ],
					'cs_custom_button_buttons_bg'         => $post_data[ 'cs_custom_button_buttons_bg' ],
					'cs_custom_button_buttons_text_color' => $post_data[ 'cs_custom_button_buttons_text_color' ],
					'cs_deny_all_buttons_bg'              => $post_data[ 'cs_deny_all_buttons_bg' ],
					'cs_deny_all_buttons_text_color'      => $post_data[ 'cs_deny_all_buttons_text_color' ],
					'cs_options_buttons_text_color'       => $post_data[ 'cs_options_buttons_text_color' ],
					'cs_options_buttons_bg'               => $post_data[ 'cs_options_buttons_bg' ],
					'cs_confirm_buttons_bg'               => $post_data[ 'cs_confirm_buttons_bg' ],
					'cs_confirm_buttons_text_color'       => $post_data[ 'cs_confirm_buttons_text_color' ],
					'cs_sticky_bg'                        => $post_data[ 'cs_sticky_bg' ],
					'cs_sticky_link_color'                => $post_data[ 'cs_sticky_link_color' ],
					'cs_logo'                             => $post_data[ 'cs_logo' ],
					'cs_position_vertical_list'           => $post_data[ 'cs_position_vertical_list' ],
					'cs_position_horizontal_list'         => $post_data[ 'cs_position_horizontal_list' ],
					'cs_logo_size'                        => $post_data[ 'cs_logo_size' ],
					'cs_cat_color'                        => $post_data[ 'cs_cat_color' ],
					'cs_active_toggle_color'              => $post_data[ 'cs_active_toggle_color' ],
					'cs_active_toggle_text_color'         => $post_data[ 'cs_active_toggle_text_color' ],
					'cs_main_template'                    => '',
					'cs_shortcodes_text_color'            => $post_data[ 'cs_shortcodes_text_color' ],
				)
			);

			wp_insert_post( $template_data );

			$this->renderSuccessMessage();
		}
	}

	private function addNewCookieCategoryHandle() {
		if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'add_new_cookie_cat' ) {

			$new_slug = isset( $_POST[ 'cs_cookie_cat_name' ] ) ? sanitize_text_field( $_POST[ 'cs_cookie_cat_name' ] ) : null;

			$category = get_term_by( 'slug', $new_slug, 'cs-cookies-category' );

			if ( !$category ) {
				global $sitepress;
				$wpml_default_lang = 'en';
				$wpml_current_lang = 'en';
				if ( function_exists( 'icl_object_id' ) && $sitepress ) {
					$wpml_default_lang = $sitepress->get_default_language();
					$wpml_current_lang = ICL_LANGUAGE_CODE;
				}
				//check only in default language
				if ( $wpml_default_lang == $wpml_current_lang ) {
					$term = get_term_by( 'slug', $new_slug, 'cs-cookies-category' );
					if ( @ !$term->term_id ) {
						$cid = wp_insert_term( $new_slug, 'cs-cookies-category', array(
							'slug' => $new_slug
						) );
						if ( !is_wp_error( $cid ) ) {
							$description = array(
								'name'  => $new_slug,
								'descr' => isset( $_POST[ 'cs_cookie_cat_descr' ] ) ? wp_kses_post( wp_unslash( $_POST[ 'cs_cookie_cat_descr' ] ) ) : '',
							);
							// Get term_id, set default as 0 if not set
							$cat_id = isset( $cid[ 'term_id' ] ) ? $cid[ 'term_id' ] : 0;
							add_term_meta( $cat_id, 'cs_primary_term', 'custom', true );
							add_term_meta( $cat_id, 'cs_necessary_term', 'custom', true );
							add_term_meta( $cat_id, 'cs_ignore_this_category', '0', true );
							add_term_meta( $cat_id, 'cs_edit_cat_description_' . CMPRO_DEFAULT_LANGUAGE, $description, true );
							add_term_meta( $cat_id, 'cs_edit_cat_description_lang', array( CMPRO_DEFAULT_LANGUAGE ), true );
							add_term_meta( $cat_id, '_cs_iab_cat', isset( $_POST[ 'cs_iab_cat' ] ) ? sanitize_text_field( $_POST[ 'cs_iab_cat' ] ) : null, true );
							update_option( $new_slug . '_cat_id', $cat_id );

							$return = array(
								'cat_id' => $cat_id
							);

							wp_send_json_success( $return );
						}
					}
				}
			}
		}
	}

	private function updateCookieCategoryHandle() {
		if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'update_cookie_cat' ) {

			$the_options = ConsentMagic()->getCSOptions();
			foreach ( $the_options as $key => $value ) {
				if ( isset( $_POST[ 'cs_not_block_unassigned_cookies' ] ) && $key === 'cs_not_block_unassigned_cookies' ) {
					ConsentMagic()->updateOptions( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_not_block_unassigned_cookies' ] ) ? sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_not_block_unassigned_cookies' ] ) : '' );
				}
				if ( isset( $_POST[ 'default_font' ] ) && $key === 'default_font' ) {
					ConsentMagic()->updateOptions( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'default_font' ] ) ? sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'default_font' ] ) : '' );
				}
			}

			$cs_cookie_cat_id = sanitize_text_field( $_POST[ 'cs_cookie_cat_id' ] );
			if ( isset( $_POST[ 'cs_cookie_cat_id' ] ) && isset( $_POST[ 'cs_cookie_cat_fields' ] ) && isset( $_POST[ "cs_language_control_{$cs_cookie_cat_id}" ] ) ) {

				$fields = json_decode( wp_kses_post( stripslashes( $_POST[ 'cs_cookie_cat_fields' ] ) ) );
				if ( $fields !== false && is_array( $fields ) ) {
					$langs = array();
					foreach ( $fields as $field ) {

						$description = array(
							'name'  => sanitize_text_field( $field->name ),
							'descr' => $field->descr,
						);
						$langs[]     = sanitize_text_field( $field->lang );
						update_term_meta( $cs_cookie_cat_id, 'cs_edit_cat_description_' . sanitize_text_field( $field->lang ), $description );
					}

					if ( $_POST[ "cs_language_control_{$cs_cookie_cat_id}" ] == 1 ) {
						update_term_meta( $cs_cookie_cat_id, 'cs_edit_cat_description_lang', $langs );
						ConsentMagic()->update_language_availability( $langs );
					}
					update_term_meta( $cs_cookie_cat_id, 'cs_ignore_this_category', isset( $_POST[ 'cs_ignore_this_category' ] ) ? sanitize_text_field( $_POST[ 'cs_ignore_this_category' ] ) : null );
					update_term_meta( $cs_cookie_cat_id, '_cs_iab_cat', isset( $_POST[ 'cs_iab_cat' ] ) ? sanitize_text_field( $_POST[ 'cs_iab_cat' ] ) : null );

				}
			}
		}
	}

	private function deleteCookieCategoryHandle() {
		if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'delete_cookie_cat' && isset( $_POST[ 'cs_cookie_cat_id' ] ) ) {

			$id   = sanitize_text_field( $_POST[ 'cs_cookie_cat_id' ] );
			$term = get_term_by( 'ID', $id, 'cs-cookies-category' );

			$scripts = get_posts( array(
				'post_type'   => CMPRO_POST_TYPE_SCRIPTS,
				'numberposts' => -1,
				'post_status' => 'any',
				'tax_query'   => array(
					array(
						'taxonomy'         => 'cs-cookies-category',
						'field'            => 'term_id',
						'terms'            => $id,
						'include_children' => false
					)
				)
			) );

			$update_category = 'unassigned';
			$unassigned      = get_term_by( 'slug', $update_category, 'cs-cookies-category' );

			if ( $scripts ) {
				foreach ( $scripts as $script ) {
					update_option( 'cs_' . $script->ID . '_cookie_cat', '' );
					update_option( 'cs_' . $script->ID . '_script_cat', $update_category );
					wp_set_object_terms( $script->ID, $unassigned->term_id, 'cs-cookies-category' );
				}
			}

			$script_list = get_predefined_script_pattern();
			foreach ( $script_list as $script ) {
				$category = ConsentMagic()->getOption( $script[ 'cat_key' ] );
				if ( $category == $term->slug ) {
					ConsentMagic()->updateOptions( array( $script[ 'cat_key' ] => $update_category ) );
				}
			}

			if ( $term ) {
				wp_delete_term( $id, 'cs-cookies-category', array(
					'default'       => $unassigned->term_id,
					'force_default' => true
				) );
				delete_option( $term->slug . '_cat_id' );
			}

		}
	}

	private function deleteDesignTemplateHandle() {
		if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'delete_template' ) {

			if ( isset( $_POST[ 'template_id' ] ) ) {

				$id = sanitize_text_field( $_POST[ 'template_id' ] );

				$scripts = get_posts( array(
					'post_type'   => CMPRO_POST_TYPE,
					'numberposts' => -1,
					'post_status' => 'any',
				) );
				if ( $scripts ) {
					foreach ( $scripts as $script ) {
						$script_theme = get_post_meta( $script->ID, '_cs_theme', true );
						if ( $script_theme == $id ) {
							update_post_meta( $script->ID, '_cs_theme', get_page_id_by_path( 'cs_light_theme', '', CMPRO_TEMPLATE_POST_TYPE ) );
						}
					}
				}

				wp_delete_post( $id, true );
			}
		}
	}

	private function addRuleHandle() {
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'add_rule_form' ) {

			$unassigned         = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );
			$unassigned_id      = $unassigned->term_id;
			$categories         = get_cookies_terms_objects( null, false, $unassigned_id );
			$categories_options = array();

			if ( !empty( $categories ) ) {
				foreach ( $categories as $category ) {
					if ( isset( $_POST[ '_cs_smart_sticky_' . $category->term_id ] ) ) {
						$categories_options[ '_cs_smart_sticky_' . $category->term_id ] = sanitize_text_field( $_POST[ '_cs_smart_sticky_' . $category->term_id ] );
					}

					if ( isset( $_POST[ '_cs_smart_sticky_mobile_' . $category->term_id ] ) ) {
						$categories_options[ '_cs_smart_sticky_mobile_' . $category->term_id ] = sanitize_text_field( $_POST[ '_cs_smart_sticky_mobile_' . $category->term_id ] );
					}

					if ( isset( $_POST[ '_cs_custom_button_' . $category->term_id ] ) ) {
						$categories_options[ '_cs_custom_button_' . $category->term_id ] = sanitize_text_field( $_POST[ '_cs_custom_button_' . $category->term_id ] );
					}
				}
			}

			$post_data = array();
			array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function( &$value, $key ) use ( &$post_data ) {
				$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
			} );

			if ( !$this->admin->cs_post_exists_by_slug( $post_data[ 'cs_default_rule_name' ], CMPRO_POST_TYPE ) ) {

				$category = get_term_by( 'slug', 'rules', 'cs-category' );
				if ( $category && is_object( $category ) ) {
					$posts_in_category           = $category->count;
					$order                       = $posts_in_category;
					$category_id                 = $category->term_id;
					$cookie_data                 = array(
						'post_type'     => CMPRO_POST_TYPE,
						'post_title'    => $post_data[ 'cs_default_rule_name' ],
						'post_category' => array( $category_id ),
						'post_status'   => 'publish',
						'ping_status'   => 'closed',
						'post_author'   => 1,
						'meta_input'    => array(
							'_cs_type'                               => isset( $_POST[ '_cs_type' ] ) ? sanitize_text_field( $_POST[ '_cs_type' ] ) : null,
							'_cs_sticky'                             => isset( $_POST[ '_cs_sticky' ] ) ? sanitize_text_field( $_POST[ '_cs_sticky' ] ) : null,
							'_cs_smart_sticky'                       => isset( $_POST[ '_cs_smart_sticky' ] ) ? sanitize_text_field( $_POST[ '_cs_smart_sticky' ] ) : null,
							'_cs_smart_sticky_mobile'                => isset( $_POST[ '_cs_smart_sticky_mobile' ] ) ? sanitize_text_field( $_POST[ '_cs_smart_sticky_mobile' ] ) : null,
							'_cs_mobile_side_sticky'                 => isset( $_POST[ '_cs_mobile_side_sticky' ] ) ? sanitize_text_field( $_POST[ '_cs_mobile_side_sticky' ] ) : null,
							'_cs_custom_button'                      => isset( $_POST[ '_cs_custom_button' ] ) ? sanitize_text_field( $_POST[ '_cs_custom_button' ] ) : null,
							'_cs_bars_position'                      => isset( $_POST[ '_cs_bars_position' ] ) ? sanitize_text_field( $_POST[ '_cs_bars_position' ] ) : null,
							'_cs_bars_type'                          => isset( $_POST[ '_cs_bars_type' ] ) ? sanitize_text_field( $_POST[ '_cs_bars_type' ] ) : null,
							'_cs_top_push'                           => isset( $_POST[ '_cs_top_push' ] ) ? sanitize_text_field( $_POST[ '_cs_top_push' ] ) : null,
							'_cs_privacy_link'                       => isset( $_POST[ '_cs_privacy_link' ] ) ? sanitize_text_field( $_POST[ '_cs_privacy_link' ] ) : null,
							'_cs_close_on_scroll'                    => isset( $_POST[ '_cs_close_on_scroll' ] ) ? sanitize_text_field( $_POST[ '_cs_close_on_scroll' ] ) : null,
							'_cs_theme'                              => isset( $_POST[ '_cs_theme' ] ) ? sanitize_text_field( $_POST[ '_cs_theme' ] ) : null,
							'_cs_design_type'                        => isset( $_POST[ '_cs_design_type' ] ) ? sanitize_text_field( $_POST[ '_cs_design_type' ] ) : null,
							'_cs_deny_all_btn'                       => isset( $_POST[ '_cs_deny_all_btn' ] ) ? sanitize_text_field( $_POST[ '_cs_deny_all_btn' ] ) : null,
							'_cs_hide_close_btn'                     => isset( $_POST[ '_cs_hide_close_btn' ] ) ? sanitize_text_field( $_POST[ '_cs_hide_close_btn' ] ) : null,
							'_cs_deny_consent_for_close'             => isset( $_POST[ '_cs_deny_consent_for_close' ] ) ? sanitize_text_field( $_POST[ '_cs_deny_consent_for_close' ] ) : null,
							'_cs_predefined_rule'                    => 0,
							'_cs_target'                             => isset( $_POST[ '_cs_target' ] ) ? sanitize_text_field( $_POST[ '_cs_target' ] ) : null,
							'_cs_us_states_target'                   => isset( $_POST[ '_cs_us_states_target' ] ) ? sanitize_text_field( $_POST[ '_cs_us_states_target' ] ) : null,
							'_cs_custom_text'                        => isset( $_POST[ '_cs_custom_text' ] ) ? sanitize_text_field( $_POST[ '_cs_custom_text' ] ) : null,
							'_cs_order'                              => $order,
							'_cs_track_analytics'                    => isset( $_POST[ '_cs_track_analytics' ] ) ? sanitize_text_field( $_POST[ '_cs_track_analytics' ] ) : null,
							'_cs_block_content'                      => isset( $_POST[ '_cs_block_content' ] ) ? sanitize_text_field( $_POST[ '_cs_block_content' ] ) : null,
							'_cs_refresh_after_consent'              => isset( $_POST[ '_cs_refresh_after_consent' ] ) ? sanitize_text_field( $_POST[ '_cs_refresh_after_consent' ] ) : 0,
							'_cs_enable_rule'                        => isset( $_POST[ '_cs_enable_rule' ] ) ? sanitize_text_field( $_POST[ '_cs_enable_rule' ] ) : null,
							'_cs_no_ip_rule'                         => isset( $_POST[ '_cs_no_ip_rule' ] ) ? sanitize_text_field( $_POST[ '_cs_no_ip_rule' ] ) : null,
							'_excluded_from_consent_storing'         => isset( $_POST[ '_excluded_from_consent_storing' ] ) ? sanitize_text_field( $_POST[ '_excluded_from_consent_storing' ] ) : null,
							'_cs_showing_rule_until_express_consent' => isset( $_POST[ '_cs_showing_rule_until_express_consent' ] ) ? sanitize_text_field( $_POST[ '_cs_showing_rule_until_express_consent' ] ) : null,
							'_cs_native_scripts'                     => isset( $_POST[ '_cs_native_scripts' ] ) ? sanitize_text_field( $_POST[ '_cs_native_scripts' ] ) : null,
							'_cs_use_meta_ldu'                       => isset( $_POST[ '_cs_use_meta_ldu' ] ) ? sanitize_text_field( $_POST[ '_cs_use_meta_ldu' ] ) : null,
						)
					);
					$cookie_data[ 'meta_input' ] = array_merge( $cookie_data[ 'meta_input' ], $categories_options );

					$post_id = wp_insert_post( $cookie_data );
					wp_set_object_terms( $post_id, $cookie_data[ 'post_category' ], 'cs-category' );
					$options   = get_lang_meta_list();
					$all_langs = get_language_list();
					foreach ( $options as $option ) {
						$key_langs               = array();
						$lang_options[ $option ] = array();
						foreach ( $_POST as $item_name => $val ) {

							if ( gettype( $val ) === 'string' ) {
								$val = wp_kses_post( wp_unslash( $val ) );
							} else {
								continue;
							}
							$item_name = sanitize_text_field( $item_name );
							if ( strripos( $item_name, $option ) !== false ) {
								$lang = str_replace( $option . '_', '', $item_name );

								if ( $lang != $option && array_key_exists( $lang, $all_langs ) ) {
									array_push( $key_langs, $lang );
									update_post_meta( $post_id, $item_name, $val );
								}
							}
						}
						update_post_meta( $post_id, $option . '_lang', $key_langs );
						ConsentMagic()->update_language_availability( $key_langs );
					}
				}
			}

			$this->renderSuccessMessage();
		}
	}

	private function addScriptHandle() {
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'add_script_form' ) {

			$post_data = array();

			array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function( &$value, $key ) use ( &$post_data ) {
				$k = sanitize_text_field( $key );
				if ( in_array( $k, get_text_editor_fields() ) ) {
					$post_data[ sanitize_text_field( $k ) ] = wp_kses_post( wp_unslash( $value ) );
				} else {
					$post_data[ sanitize_text_field( $k ) ] = sanitize_text_field( $value );
				}
			} );

			if ( !$this->admin->cs_post_exists_by_slug( $post_data[ 'cs_default_script_name' ], CMPRO_POST_TYPE_SCRIPTS ) ) {

				$category = get_term_by( 'slug', $post_data[ 'add_new_script_select' ], 'cs-cookies-category' );
				if ( $category && is_object( $category ) ) {

					$needle = isset( $_POST[ 'heedle' ] ) ? sanitize_text_field( $_POST[ 'heedle' ] ) : null;
					$needle = cs_sanitize_url( $needle );

					$category_id = $category->term_id;
					$cookie_data = array(
						'post_type'     => CMPRO_POST_TYPE_SCRIPTS,
						'post_title'    => $post_data[ 'cs_default_script_name' ],
						'post_category' => array( $category_id ),
						'post_status'   => 'publish',
						'ping_status'   => 'closed',
						'post_author'   => 1,
						'meta_input'    => array(
							'cs_default_script_desc'      => $post_data[ 'cs_default_script_desc' ],
							'cs_default_script_js_heedle' => $needle
						)
					);
					$post_id     = wp_insert_post( $cookie_data );
					wp_set_object_terms( $post_id, $cookie_data[ 'post_category' ], 'cs-cookies-category' );
					add_option( 'cs_' . sanitize_title( $post_data[ 'cs_default_script_name' ] ) . '_' . $post_id . '_script_enable', '1' );
					add_option( 'cs_' . $post_id . '_script_cat', $post_data[ 'add_new_script_select' ] );
				}
			}

			$this->renderSuccessMessage();
		}
	}

	private function updateScriptHandle() {
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_script_form' ) {

			$post_data = array();

			array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function( &$value, $key ) use ( &$post_data ) {
				$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
			} );

			$post_id    = $post_data[ 'cs_script_id' ];
			$script_cat = isset( $_POST[ 'cs_' . $post_id . '_script_cat' ] ) ? sanitize_text_field( $_POST[ 'cs_' . $post_id . '_script_cat' ] ) : null;
			$category   = get_term_by( 'slug', $script_cat, 'cs-cookies-category' );
			if ( $category && is_object( $category ) ) {
				$category_id = $category->term_id;
				wp_set_object_terms( $post_id, $category_id, 'cs-cookies-category' );
				update_option( 'cs_' . $script_cat . '_' . $post_id . '_script_enable', true );
				update_option( 'cs_' . $post_id . '_script_cat', $script_cat );
			}

			$needle = isset( $_POST[ 'heedle' ] ) ? sanitize_text_field( $_POST[ 'heedle' ] ) : null;
			$needle = cs_sanitize_url( $needle );

			$template_data = array(
				'ID'         => $post_id,
				'meta_input' => array(
					'cs_default_script_desc'      => isset( $_POST[ 'cs_default_script_desc' ] ) ? wp_kses_post( wp_unslash( $_POST[ 'cs_default_script_desc' ] ) ) : null,
					'cs_default_script_js_heedle' => $needle
				)
			);

			wp_update_post( $template_data );

			$this->renderSuccessMessage();
		}
	}

	private function addCookieHandle() {
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'add_cookie_form' ) {

			$post_data = array();
			array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function( &$value, $key ) use ( &$post_data ) {
				$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
			} );

			if ( !$this->admin->cs_post_exists_by_slug( $post_data[ 'cs_default_cookie_name' ], CMPRO_POST_TYPE_COOKIES ) ) {

				$category = get_term_by( 'slug', $post_data[ 'add_new_cookie_select' ], 'cs-cookies-category' );
				if ( $category && is_object( $category ) ) {
					$category_id = $category->term_id;
					$cookie_data = array(
						'post_type'     => CMPRO_POST_TYPE_COOKIES,
						'post_title'    => $post_data[ 'cs_default_cookie_name' ],
						'post_category' => array( $category_id ),
						'post_status'   => 'publish',
						'ping_status'   => 'closed',
						'post_author'   => 1,
						'meta_input'    => array(
							'cs_default_cookie_desc' => $post_data[ 'cs_default_cookie_desc' ],
						)
					);
					$post_id     = wp_insert_post( $cookie_data );
					wp_set_object_terms( $post_id, $cookie_data[ 'post_category' ], 'cs-cookies-category' );
					add_option( 'cs_' . sanitize_title( $post_data[ 'cs_default_cookie_name' ] ) . '_' . $post_id . '_cookie_enable', '1' );
					add_option( 'cs_' . $post_id . '_cookie_cat', $post_data[ 'add_new_cookie_select' ] );
				}
			}

			$this->renderSuccessMessage();
		}
	}

	private function updateCookieHandle() {
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_cookie_form' ) {

			$post_data = array();
			array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function( &$value, $key ) use ( &$post_data ) {
				$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
			} );

			$post_id    = $post_data[ 'cs_cookie_id' ];
			$script_cat = isset( $_POST[ 'cs_' . $post_id . '_cookie_cat' ] ) ? sanitize_text_field( $_POST[ 'cs_' . $post_id . '_cookie_cat' ] ) : null;
			$category   = get_term_by( 'slug', $script_cat, 'cs-cookies-category' );
			if ( $category && is_object( $category ) ) {
				$category_id = $category->term_id;
				wp_set_object_terms( $post_id, $category_id, 'cs-cookies-category' );
				update_option( 'cs_' . $script_cat . '_' . $post_id . '_cookie_enable', true );
				update_option( 'cs_' . $post_id . '_cookie_cat', $script_cat );
			}
			$template_data = array(
				'ID'         => $post_id,
				'meta_input' => array(
					'cs_default_cookie_desc' => isset( $_POST[ 'cs_default_cookie_desc' ] ) ? sanitize_text_field( $_POST[ 'cs_default_cookie_desc' ] ) : null,
				)
			);

			wp_update_post( $template_data );
			$this->renderSuccessMessage();
		}
	}

	public function checkFlow( $path ) {
		if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
			settings_errors();

			if ( CMPRO_LICENSE_TYPE == 'edd' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-edd.php';
			} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-wc.php';
			}
		} elseif ( !isset( $_GET[ 'rule_id' ] ) && !isset( $_GET[ 'new_rule' ] ) && !isset( $_GET[ 'primary_rule_id' ] ) && !isset( $_GET[ 'new_cookie' ] ) && !isset( $_GET[ 'cookie_id' ] ) && !isset( $_GET[ 'new_script' ] ) && !isset( $_GET[ 'script_id' ] ) && !isset( $_GET[ 'design_template' ] ) ) {
			require_once CMPRO_PLUGIN_VIEWS_PATH . $path;
		}
	}

}

