<?php

namespace ConsentMagicPro;

if ( !defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class CS_AdminPageSettings extends CS_AdminPage implements CS_Page {

	public function renderPage() {

		$this->manageCSPermissions();

		$this->disableTestModeHandle();
		$this->clearTestConsentHandle();
		$this->updateAdminSettingsHandle();

		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'cs_restore_translations' ) {
			$this->admin->loadTranslations( true );
			$this->admin->loadCategoriesTranslations( true );
			$this->renderSuccessMessage();
		}

		$this->restartSetupHandle();

		$this->checkFlow( 'admin/settings/html-settings.php' );
	}

	private function disableTestModeHandle() {
		// Get options:
		$the_options = ConsentMagic()->getCSOptions();

		if ( isset( $_GET[ 'cs_update_action' ] ) && $_GET[ 'cs_update_action' ] == 'cs_test_mode_disable' ) {
			// Check nonce:
			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

			$cs_test_mode = array(
				'cs_test_mode' => false
			);

			foreach ( $the_options as $key => $value ) {
				if ( $key == 'cs_test_mode' ) {
					ConsentMagic()->updateOptions( $cs_test_mode );
				}
			}

			$this->renderSuccessMessage();

			wp_redirect( remove_query_arg( 'cs_update_action', false ) );
		}
	}

	private function clearTestConsentHandle() {
		if ( isset( $_GET[ 'cs_update_action' ] ) && $_GET[ 'cs_update_action' ] == 'cs_test_consent_clear' ) {
			// Check nonce:
			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );
			$consent_version_test = ConsentMagic()->cs_get_consent_version_test();
			if ( !empty( $consent_version_test ) ) {
				$consent_version_test = $consent_version_test + 1;
				update_option( 'wt_cs_consent_version_test', $consent_version_test );
			}

			$this->renderSuccessMessage();

			wp_redirect( remove_query_arg( 'cs_update_action', false ) );
		}
	}

	private function updateAdminSettingsHandle() {
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_admin_settings_form' ) {

			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );
			$permissions = ( isset( $_POST[ 'permissions' ] ) ? sanitize_text_field( $_POST[ 'permissions' ] ) : '' ) . ',administrator';
			$permissions = explode( ",", $permissions );

			$ignore_users = isset( $_POST[ 'ignore_users' ] ) ? sanitize_text_field( $_POST[ 'ignore_users' ] ) : '';
			$ignore_users = explode( ",", $ignore_users );

			$ignore_users_ip = isset( $_POST[ 'ignore_users_ip' ] ) ? sanitize_text_field( $_POST[ 'ignore_users_ip' ] ) : '';
			$ignore_users_ip = explode( ",", $ignore_users_ip );

			$important_emails = isset( $_POST[ 'important_emails' ] ) ? sanitize_text_field( $_POST[ 'important_emails' ] ) : '';
			$emails           = explode( ",", $important_emails );
			$emails_save      = array();

			if ( !empty( $emails ) ) {
				foreach ( $emails as $email ) {
					if ( is_email( $email ) ) {
						$emails_save[] = $email;
					}
				}
			}

			// Get options:
			$the_options = ConsentMagic()->getCSOptions();

			foreach ( $the_options as $key => $value ) {
				if ( $key == 'cs_admin_permissions' ) {
					update_option( 'cs_admin_permissions', $permissions );
				} else if ( $key == 'cs_send_important_emails' ) {
					update_option( 'cs_send_important_emails', $emails_save );
				} else if ( $key == 'cs_admin_ignore_users' ) {
					update_option( 'cs_admin_ignore_users', $ignore_users );
				} else if ( $key == 'cs_admin_ignore_users_ip' ) {
					update_option( 'cs_admin_ignore_users_ip', $ignore_users_ip );
				} else if ( $key == 'cs_scanner_module' && isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) {
					$csmart_admin_modules = get_option( 'csmart_admin_modules' );
					if ( $csmart_admin_modules === false ) {
						$csmart_admin_modules = array();
					}
					$csmart_admin_modules[ 'scanner' ] = ( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_scanner_module' ] == true ) ? 1 : 0;
					update_option( 'csmart_admin_modules', $csmart_admin_modules );
				} else if ( $key == 'cs_cross_domain_tracking_domain' ) {
					$needle = isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ? sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) : null;
					$needle = cs_sanitize_url( $needle );
					ConsentMagic()->updateOptions( array( 'cs_cross_domain_tracking_domain' => $needle ) );
				} else if ( $key == 'cs_language_availability' ) {
					$income_langs = $_POST[ 'cs' ][ $this->plugin_name ][ $key ];
					if ( is_array( $income_langs ) ) {
						array_walk( $income_langs, array(
							ConsentMagic(),
							'cs_sanitize_array'
						) );

						$language_availability = ConsentMagic()->getOption( 'cs_language_availability' );
						foreach ( $income_langs as $k => $lang ) {
							if ( $k != CMPRO_DEFAULT_LANGUAGE ) {
								$language_availability[ $k ] = $lang;
							}
						}
						ksort( $language_availability );
						ConsentMagic()->updateOptions( array( 'cs_language_availability' => $language_availability ) );
					}
				} else {
					if ( !isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key . '_0' ] ) && isset( $_POST[ 'cs' ][ $this->plugin_name ] ) ) {
						$key_langs = array();
						$all_langs = get_language_list();
						$lang_save = false;
						foreach ( $_POST[ 'cs' ][ $this->plugin_name ] as $post_key => $post_val ) {
							$post_key = sanitize_text_field( $post_key );
							$post_val = sanitize_text_field( $post_val );
							if ( strripos( $post_key, $key ) !== false ) {
								$lang = str_replace( $key . '_', '', $post_key );
								if ( $lang != $post_key && array_key_exists( $lang, $all_langs ) ) {
									ConsentMagic()->updateLangOptions( array( $key => sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $post_key ] ) ), $lang );
									array_push( $key_langs, $lang );
									$lang_save = true;
								}
							}
						}

						if ( $lang_save ) {
							ConsentMagic()->updateOptions( array( $key . '_lang' => $key_langs ) );
							ConsentMagic()->update_language_availability( $key_langs );
						}
					}

					if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) {
						$setting = $_POST[ 'cs' ][ $this->plugin_name ][ $key ];
						if ( is_array( $setting ) ) {
							array_walk( $setting, array(
								ConsentMagic(),
								'cs_sanitize_array'
							) );
						} else {
							$setting = sanitize_text_field( $setting );
						}

						ConsentMagic()->updateOptions( array( $key => $setting ) );
					}
				}
			}

			foreach ( $_POST as $item_name => $val ) {
				if ( get_option( sanitize_text_field( $item_name ) ) !== false ) {
					update_option( sanitize_text_field( $item_name ), sanitize_text_field( $val ) );
				}
			}

			$this->renderSuccessMessage();
		}
	}

	private function restartSetupHandle() {
		//Restart Setup Process
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'restart_setup_process' ) {

			if ( ConsentMagic()->getOption( 'cs_deactivation_db_clear' ) == 1 ) {
				require_once CMPRO_PLUGIN_PATH . 'includes/CS_Uninstall.php';
				require_once CMPRO_PLUGIN_PATH . 'includes/CS_Activator.php';

				CS_Uninstall::deactivation( false );

				ConsentMagic()->resetToDefaults();
				ConsentMagic()->check_tables();

				$this->admin->create_taxonomy();
				$this->admin->cs_insert_templates_lists();
				$this->admin->cs_insert_cookie_lists();

				( new CS_Activator )->activate();

				//install tables
				$scanner_module = new CS_Scanner_Module;
				$scanner_module->install_tables();

			} else {

				$id = get_post_id_by_slug( 'cs_gdpr_rule' );
				wp_delete_post( $id, true );
				$id = get_post_id_by_slug( 'cs_ldu_rule' );
				wp_delete_post( $id, true );
				$id = get_post_id_by_slug( 'cs_rest_of_world_rule' );
				wp_delete_post( $id, true );
				$id = get_post_id_by_slug( 'cs_iab_rule' );
				wp_delete_post( $id, true );

				if ( !is_multisite() ) {
					delete_option( 'cs_policy_existing_page' );
				} else {

					global $wpdb;
					$blog_ids         = $wpdb->get_col( $wpdb->prepare( 'SELECT blog_id FROM %1$s', $wpdb->blogs ) );
					$original_blog_id = get_current_blog_id();

					foreach ( $blog_ids as $blog_id ) {
						switch_to_blog( $blog_id );
						delete_site_option( 'cs_policy_existing_page' );
					}
					switch_to_blog( $original_blog_id );
				}

				ConsentMagic()->deleteOption( 'cs_script_blocking_enabled' );
				ConsentMagic()->updateOptions( array( 'default_font' => '' ) );
				ConsentMagic()->updateOptions( array( 'cs_check_flow' => false ) );

			}

			$this->renderSuccessMessage();
		}
	}
}