<?php

namespace ConsentMagicPro;

// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
	die;
}

$cs_language_availability = ConsentMagic()->getOption( 'cs_language_availability' );
$language_list            = get_language_list();
$lang_options             = array();
foreach ( $cs_language_availability as $key => $lang ) {
	if ( isset( $language_list[ $key ] ) ) {

		$lang_options[ $key ] = array(
			'enable' => $lang,
			'name'   => $language_list[ $key ][ 'name' ],
			'label'  => $language_list[ $key ][ 'label' ],
		);
	}
}
$current_lang             = get_general_language( get_locale() );
$cs_user_default_language = ConsentMagic()->getOption( 'cs_user_default_language' );
$cs_language_availability = ConsentMagic()->getOption( 'cs_language_availability' );
if ( isset( $cs_language_availability[ $current_lang ] ) && $cs_language_availability[ $current_lang ] == 0 ) {
	$current_lang = $cs_user_default_language;
}

?>

<div class="container">
    <div class="rules-wrap-border">
        <div class="row rules-wrap">
            <div class="col">
                <div class="row">
                    <div class="col-1">
						<?php echo render_switcher_input( 'cs_test_mode' ); ?>
                    </div>

                    <div class="col-10">
                        <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Enable test mode', 'consent-magic' ); ?></h3>
                        <p><?php esc_html_e( 'Only Admin will see the consent dialog. You will have a button in the top bar to "Delete the test consent".', 'consent-magic' ); ?></p>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="rules-wrap-border">
        <div class="row rules-wrap">
            <div class="col-1">
				<?php echo render_switcher_input( 'cs_deactivation_db_clear' ); ?>
            </div>

            <div class="col-10">
                <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Remove all data when deactivating the plugin', 'consent-magic' ); ?></h3>
            </div>
        </div>
    </div>

	<?php if ( isWooCommerceActive() ) { ?>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col">
                    <div class="row">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_store_consent_for_wc_orders' ); ?>
                        </div>

                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Store Consent for WooCommerce orders', 'consent-magic' ); ?></h3>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col">
                    <div class="row">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_admin_email_consent_for_wc_orders' ); ?>
                        </div>

                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Send consent data with the WooCommerce "New Order" email', 'consent-magic' ); ?></h3>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col">
                    <div class="row" style="margin-top: 25px;">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_customer_email_consent_for_wc_orders' ); ?>
                        </div>

                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Send consent data with the WooCommerce "Processing Order" email', 'consent-magic' ); ?></h3>
                        </div>
                    </div>

                    <div class="card card_settings">
                        <div class="card-header">
                            <div class="row">
                                <div class="col">
                                    <p style="font-size: 16px; font-weight: 600;"><?php esc_html_e( 'Your privacy options text', 'consent-magic' ); ?></p>
                                </div>

                                <div class="col-2 right-aligned">
                                    <button type="button" class="btn btn-link card-collapse">
										<?php esc_html_e( 'Edit', 'consent-magic' ); ?> <i class="icon-down"></i>
                                    </button>
                                </div>
                            </div>
                        </div>

                        <div class="card-body" style="display: none;">

							<?php
							$lang_list = ConsentMagic()->getOption( 'cs_customer_email_consent_type_lang' );
							if ( is_array( $lang_list ) ) {
								$key_lang   = array_search( $current_lang, $lang_list );
								$attr_value = ConsentMagic()->getOption( 'cs_customer_email_consent_type_' . $current_lang );
								if ( empty( $attr_value ) || $key_lang === false ) {
									$display_lang = CMPRO_DEFAULT_LANGUAGE;
								} else {
									$display_lang = $lang_list[ $key_lang ];
								}
							} else {
								$display_lang = CMPRO_DEFAULT_LANGUAGE;
							}
							?>
                            <div class="cart_line_item">
                                <div class="label_row">
                                    <h4><?php esc_html_e( 'Consent type:', 'consent-magic' ); ?></h4>
                                </div>

                                <div class="input_row input_row_default">
                                    <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                        <div class="row input_row cs_data_render">
                                            <div class="cs_data_render_wrap">
												<?php renderTextInput( 'cs_customer_email_consent_type', null, $display_lang, false, '', 'js-control-element' ); ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="sub-card sub-card-inputs">
                                    <div class="sub-card-header">
                                        <div class="row">
                                            <div class="col">
	                                            <?php render_additional_lang_button( 'Consent type' ); ?>
                                            </div>

                                            <div class="col-2 right-aligned">
                                                <button type="button" class="btn btn-link sub-card-collapse">
													<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                            class="icon-down"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="sub-card-body" style="display: none;">
                                        <div class="language_list">
											<?php
											if ( !empty( $lang_list ) && is_array( $lang_list ) ) :
												foreach ( $lang_list as $lang ) :
													if ( $lang != $display_lang ) : ?>
                                                        <div class="row cart_line_item"
                                                             style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                            <div class="col-1 cs-delete-lang-wrap">
                                                                <span class="icon-minus cs-delete-lang"></span>
                                                            </div>

                                                            <div class="col-11 input_row">
                                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                        <div class="cs_data_render_wrap">
																			<?php renderTextInput( 'cs_customer_email_consent_type', null, $lang, false, '', 'js-control-element' ); ?>
                                                                        </div>
                                                                    </div>

                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguages( false, 'cs_customer_email_consent_type', $lang, false, false, 'renderTextInput', false, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
													<?php endif;
												endforeach;
											endif;
											?>
                                        </div>

                                        <div class="add_new_lang_wrap">
	                                        <?php render_add_lang_button( 'cs_customer_email_consent_type', 'renderTextInput' ); ?>
                                            <div style="display: none" class="add_new_lang">
                                                <div class="row cart_line_item">
                                                    <div class="col-1 cs-delete-lang-wrap">
                                                        <span class="icon-minus cs-delete-lang"></span>
                                                    </div>

                                                    <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                        <div class="row input_row cs_data_render">
                                                        </div>
                                                        <div class="row cs_data_render_buttons">
															<?php renderSelectLanguagesNew( false, 'cs_customer_email_consent_type', false, 'renderTextInput', false, '240px' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
							<?php
							$lang_list = ConsentMagic()->getOption( 'cs_customer_email_rule_name_lang' );
							if ( is_array( $lang_list ) ) {
								$key_lang   = array_search( $current_lang, $lang_list );
								$attr_value = ConsentMagic()->getOption( 'cs_customer_email_rule_name_' . $current_lang );
								if ( empty( $attr_value ) || $key_lang === false ) {
									$display_lang = CMPRO_DEFAULT_LANGUAGE;
								} else {
									$display_lang = $lang_list[ $key_lang ];
								}
							} else {
								$display_lang = CMPRO_DEFAULT_LANGUAGE;
							}
							?>
                            <div class="cart_line_item">
                                <div class="label_row">
                                    <h4><?php esc_html_e( 'Rule\'s name:', 'consent-magic' ); ?></h4>
                                </div>

                                <div class="input_row input_row_default">
                                    <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                        <div class="row input_row cs_data_render">
                                            <div class="cs_data_render_wrap">
												<?php renderTextInput( 'cs_customer_email_rule_name', null, $display_lang, false, '', 'js-control-element' ); ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="sub-card sub-card-inputs">
                                    <div class="sub-card-header">
                                        <div class="row">
                                            <div class="col">
	                                            <?php render_additional_lang_button( 'Rule\'s name' ); ?>
                                            </div>

                                            <div class="col-2 right-aligned">
                                                <button type="button" class="btn btn-link sub-card-collapse">
													<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                            class="icon-down"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="sub-card-body" style="display: none;">
                                        <div class="language_list">
											<?php
											if ( !empty( $lang_list ) && is_array( $lang_list ) ) :
												foreach ( $lang_list as $lang ) :
													if ( $lang != $display_lang ) : ?>
                                                        <div class="row cart_line_item"
                                                             style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                            <div class="col-1 cs-delete-lang-wrap">
                                                                <span class="icon-minus cs-delete-lang"></span>
                                                            </div>

                                                            <div class="col-11 input_row">
                                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                        <div class="cs_data_render_wrap">
																			<?php renderTextInput( 'cs_customer_email_rule_name', null, $lang, false, '', 'js-control-element' ); ?>
                                                                        </div>
                                                                    </div>

                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguages( false, 'cs_customer_email_rule_name', $lang, false, false, 'renderTextInput', false, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
													<?php endif;
												endforeach;
											endif;
											?>
                                        </div>

                                        <div class="add_new_lang_wrap">
	                                        <?php render_add_lang_button( 'cs_customer_email_rule_name', 'renderTextInput' ); ?>
                                            <div style="display: none" class="add_new_lang">
                                                <div class="row cart_line_item">
                                                    <div class="col-1 cs-delete-lang-wrap">
                                                        <span class="icon-minus cs-delete-lang"></span>
                                                    </div>

                                                    <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                        <div class="row input_row cs_data_render">
                                                        </div>
                                                        <div class="row cs_data_render_buttons">
															<?php renderSelectLanguagesNew( false, 'cs_customer_email_rule_name', false, 'renderTextInput', false, '240px' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
							<?php
							$lang_list = ConsentMagic()->getOption( 'cs_customer_email_consent_expressed_lang' );
							if ( is_array( $lang_list ) ) {
								$key_lang   = array_search( $current_lang, $lang_list );
								$attr_value = ConsentMagic()->getOption( 'cs_customer_email_consent_expressed_' . $current_lang );
								if ( empty( $attr_value ) || $key_lang === false ) {
									$display_lang = CMPRO_DEFAULT_LANGUAGE;
								} else {
									$display_lang = $lang_list[ $key_lang ];
								}
							} else {
								$display_lang = CMPRO_DEFAULT_LANGUAGE;
							}
							?>
                            <div class="cart_line_item">
                                <div class="label_row">
                                    <h4><?php esc_html_e( 'Consent expressed:', 'consent-magic' ); ?></h4>
                                </div>

                                <div class="input_row input_row_default">
                                    <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                        <div class="row input_row cs_data_render">
                                            <div class="cs_data_render_wrap">
												<?php renderTextInput( 'cs_customer_email_consent_expressed', null, $display_lang, false, '', 'js-control-element' ); ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="sub-card sub-card-inputs">
                                    <div class="sub-card-header">
                                        <div class="row">
                                            <div class="col">
                                                <?php render_additional_lang_button( 'Consent expressed' ); ?>
                                            </div>

                                            <div class="col-2 right-aligned">
                                                <button type="button" class="btn btn-link sub-card-collapse">
													<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                            class="icon-down"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="sub-card-body" style="display: none;">
                                        <div class="language_list">
											<?php
											if ( !empty( $lang_list ) && is_array( $lang_list ) ) :
												foreach ( $lang_list as $lang ) :
													if ( $lang != $display_lang ) : ?>
                                                        <div class="row cart_line_item"
                                                             style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                            <div class="col-1 cs-delete-lang-wrap">
                                                                <span class="icon-minus cs-delete-lang"></span>
                                                            </div>

                                                            <div class="col-11 input_row">
                                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                        <div class="cs_data_render_wrap">
																			<?php renderTextInput( 'cs_customer_email_consent_expressed', null, $lang, false, '', 'js-control-element' ); ?>
                                                                        </div>
                                                                    </div>

                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguages( false, 'cs_customer_email_consent_expressed', $lang, false, false, 'renderTextInput', false, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
													<?php endif;
												endforeach;
											endif;
											?>
                                        </div>

                                        <div class="add_new_lang_wrap">
	                                        <?php render_add_lang_button( 'cs_customer_email_consent_expressed', 'renderTextInput' ); ?>
                                            <div style="display: none" class="add_new_lang">
                                                <div class="row cart_line_item">
                                                    <div class="col-1 cs-delete-lang-wrap">
                                                        <span class="icon-minus cs-delete-lang"></span>
                                                    </div>

                                                    <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                        <div class="row input_row cs_data_render">
                                                        </div>
                                                        <div class="row cs_data_render_buttons">
															<?php renderSelectLanguagesNew( false, 'cs_customer_email_consent_expressed', false, 'renderTextInput', false, '240px' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

	<?php } ?>

	<?php if ( isEddActive() ) { ?>
        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col">
                    <div class="row">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_store_consent_for_edd_orders' ); ?>
                        </div>

                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Store Consent for Easy Digital Downloads orders', 'consent-magic' ); ?></h3>
                        </div>
                    </div>
                </div>
            </div>
        </div>
	<?php } ?>

    <div class="rules-wrap-border">
        <div class="row rules-wrap">
            <div class="col">
                <div class="row">
					<?php if ( !isPYSActivated() ) : ?>
                        <p style="font-size: 12px;">
							<?php echo sprintf( esc_html__( 'You need install and enable Pixel Your Site Plugin for this option. For more information visit site %s', 'consent-magic' ), '<a href="http://www.pixelyoursite.com/" target="_blank" rel="nofollow">Pixelyoursite.com</a>' ); ?>
                        </p>
					<?php endif; ?>
                    <div class="row" <?php echo !isPYSActivated() ? 'style="opacity: 0.3; pointer-events: none;"' : ''; ?>>
                        <div class="col-1 row-property">
							<?php echo render_switcher_input( 'cs_consent_for_pys' ); ?>
                        </div>

                        <div class="col-10 row-sub-property">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Pixel YourSite First-Party Tracking', 'consent-magic' ); ?></h3>
                            <p><?php esc_html_e( 'PixelYourSite can track the traffic source, landing page, and UTMs and use the data for events parameters, WooCommerce, or Easy Digital Downloads first-party reports. You can configure the type of consent for this functionality.', 'consent-magic' ); ?></p>
                            <div class="row-sub-property-toggle" style="padding: 10px;">
                                <div class="row" style="border: none;padding: 0;">
                                    <div class="col-1">
										<?php echo render_switcher_input( 'cs_track_before_consent_expressed_for_pys' ); ?>
                                    </div>

                                    <div class="col-10">
                                        <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Always track before consent is expressed.', 'consent-magic' ); ?></h3>
                                        <p><?php esc_html_e( 'PixelYourSite will track and use this data for "Ask before tracking" before any consent is expressed by the website visitor.', 'consent-magic' ); ?></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="row">
						<?php if ( !isPYSActivated() && isFbWooActivated() ) { ?>
                            <div class="row" style="width: 100%;">
                                <div class="col-1 row-property">
									<?php echo render_switcher_input( 'cs_fb_woo_capi_enabled' ); ?>
                                </div>
                                <div class="col-10 row-sub-property">
                                    <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Facebook for WooCommerce - Control CAPI events', 'consent-magic' ); ?></h3>
									<?php if ( (int) ConsentMagic()->getOption( 'cs_enable_site_cache' ) === 0 ): ?>
                                        <p><?php esc_html_e( 'If you enable this option, rules using "Ask before tracking" consent type will refresh the page after consent is expressed by the visitor.', 'consent-magic' ); ?></p>
									<?php endif; ?>
                                </div>
                            </div>
						<?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="rules-wrap-border">
        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col">
                    <div class="row">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_block_video_personal_data' ); ?>
                        </div>

                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Show the video but block personal data tracking when required by the rule and user consent', 'consent-magic' ); ?></h3>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col-12">
                    <div class="row">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_enable_site_cache' ); ?>
                        </div>

                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Site uses cache', 'consent-magic' ); ?></h3>
                            <p><?php esc_html_e( 'Enable this option if the site uses caching plugins (in particular, page caching), as well as caching on the hosting side.', 'consent-magic' ); ?></p>
                            <p style="color:#f30000;"><?php esc_html_e( 'Usage note: after updating the plugin settings, you need to clear the cache.', 'consent-magic' ); ?></p>
                            <p style="margin-bottom: 4px;">Additionally, you can add these exceptions to "Exclude JavaScript Files" in minification and delay options:</p>
                            <p style="margin-bottom: 0;"><code>/wp-content/plugins/consent-magic-pro/(.*).js</code></p>
                            <p style="margin-bottom: 12px;"><code>consent-magic-js-extra</code></p>
                            <p style="margin-bottom: 0;">Note: These exceptions may vary slightly depending on the caching plugin. In most cases it won't be necessary to add them.</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col-12">
                    <div class="row">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_cross_domain_tracking' ); ?>
                        </div>

                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Subdomain tracking', 'consent-magic' ); ?></h3>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-1"></div>
                        <div class="col-10">
                            <div class="mt-20"><?php esc_html_e( 'To enable the cross-domain option to work correctly, you must specify the top-level domain in the CM settings for all your sites.', 'consent-magic' ); ?></div>
                            <div class="mb-10 mt-5"><?php echo wp_kses_post( __('For example, if your main site is <code>yoursite.com</code> and a subsite is <code>shop.yoursite.com</code>, you need to specify <code>yoursite.com</code> in the settings of both sites.', 'consent-magic' ) ); ?></div>
                            <input type="text"
                                   name="<?php echo esc_attr( "cs[" . ConsentMagic()->plugin_name . "][cs_cross_domain_tracking_domain]" ); ?>"
                                   id="cs_cross_domain_tracking_domain"
                                   value="<?php echo esc_attr( ConsentMagic()->getOption( 'cs_cross_domain_tracking_domain' ) ); ?>"
                                   style="width: 100%;"/>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="card rules-wrap-no-border">
            <div class="card-header">
                <div class="row">
                    <div class="col">
                        <h2 class="card_title"><?php esc_html_e( 'Translations', 'consent-magic' ); ?></h2>
                    </div>

                    <div class="col-2 right-aligned">
                        <button type="button" class="btn btn-link card-collapse">
							<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                    class="icon-down"></i>
                        </button>
                    </div>
                </div>
            </div>

            <div class="card-body" style="display: none;">
                <div class="cart_line_item input_row_default">
                    <div class="mb-30">
                        <?php echo esc_html__( 'The content will be displayed in the following language according to the WordPress language settings. If a multilingual plugin changes the language based on the user\'s location, the rule\'s content will also use that language when possible. You can edit or add translations on', 'consent-magic' ) . '<a href="' . esc_url( get_admin_url() . 'admin.php?page=consent-magic&tab=cs-text' ) . '" class="link-to-nav-tab">' . 'Dashboard > Text' . '</a><br>' . esc_html__( ' Custom text and translations can be added to all rules except the IAB Rule.', 'consent-magic'); ?>
                    </div>
                    <div class="row settings_translations">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_enable_translations' ); ?>
                        </div>
                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Enable Translations', 'consent-magic' ); ?></h3>
                        </div>
                    </div>
                    <div class="row pb-20 pt-20">
                        <div class="col-1">
                        </div>
                        <div class="col-11">
                            <h4 class="indicator-label switcher-label mr-20"><?php esc_html_e( 'Default language', 'consent-magic' ); ?></h4>
							<?php renderSelectLanguages( 'cs_user_default_language', false, $cs_user_default_language, $lang_options, 'renderWpEditor', false, false, '400px' ); ?>
                            <div class="cs-line mb-20 mt-20"></div>
                            <div class="mb-20"><?php esc_html_e( 'Select available languages to display:', 'consent-magic' ); ?></div>
                            <div class="cs_languages">
								<?php
								if ( !empty( $lang_options ) ) :
									foreach ( $lang_options as $key => $lang ) :
										?>
                                        <div class="<?php echo $key !== CMPRO_DEFAULT_LANGUAGE ? 'cs_available_lang_container' : ''; ?> mb-5"
                                             style="<?php echo ( $key == $cs_user_default_language || $key === CMPRO_DEFAULT_LANGUAGE ) ? 'opacity: 0.5;pointer-events:none;' : '' ?>">
											<?php
											$names = array(
												'cs_language_availability',
												$key
											);
											echo render_static_switcher_input( $names, $lang[ 'enable' ] ); ?>
											<?php echo $lang[ 'label' ]; ?>
											<?php if ( $key === CMPRO_DEFAULT_LANGUAGE ) : ?>
                                                <span>
                                                <?php echo sprintf( '(%s)', esc_html__( 'Always ON', 'consent-magic' ) ); ?>
                                            </span>
											<?php else : ?>
                                                <span class="cs_language_message">
                                                <?php echo $key == $cs_user_default_language ? sprintf( '(%s)', esc_html__( 'Default language always ON', 'consent-magic' ) ) : ''; ?>
                                            </span>
											<?php endif; ?>
                                        </div>
									<?php
									endforeach;
								endif;
								?>
                            </div>
                            <div id="cs_language_message" style="display: none">
                                (<?php esc_html_e( 'Default language always ON', 'consent-magic' ); ?>)
                            </div>
                        </div>
                    </div>

                    <div class="cs-line mb-20 mt-10"></div>

                    <div class="centered-aligned">
                        <button type="button" class="btn btn-blue btn-right restore_translations">
							<?php esc_html_e( 'Restore the default text', 'consent-magic' ); ?>
                        </button>
                    </div>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border headline">
            <div class="rules-wrap headline">
                <div class="wrap_title">
                    <h2><?php esc_html_e( 'Cookies duration', 'consent-magic' ); ?></h2>
                </div>

                <p class="small_number"><?php esc_html_e( 'Ask for consent again after ', 'consent-magic' ); ?>
					<?php render_number_input( 'cs_expire_days', false ); ?> <?php esc_html_e( ' days. Use 0 for indefinite', 'consent-magic' ); ?>
                    .</p>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="rules-wrap headline">
                <div class="wrap_title">
                    <h2><?php esc_html_e( 'Scanner module', 'consent-magic' ); ?></h2>
                </div>

                <div class="row">
                    <div class="col">
                        <div class="row">
                            <div class="col-1">
								<?php echo render_switcher_input( 'cs_scanner_module' ); ?>
                            </div>

                            <div class="col-10">
                                <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Enable scanner module', 'consent-magic' ); ?></h3>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border headline">
            <div class="rules-wrap headline">
                <div class="wrap_title">
                    <h2><?php esc_html_e( 'Close on Scroll', 'consent-magic' ); ?></h2>
                </div>

                <p class="small_number"><?php esc_html_e( 'Close on Scroll duration ', 'consent-magic' ); ?>
					<?php render_number_input( 'cs_default_close_on_scroll', false ); ?>
                    %</p>
            </div>
        </div>

        <div class="rules-wrap-border headline">
            <div class="rules-wrap headline">
                <div class="wrap_title">
                    <h2><?php esc_html_e( 'Branding', 'consent-magic' ); ?></h2>
                </div>

                <div class="row" style="margin-bottom: 15px;">
                    <div class="col-1">
						<?php echo render_switcher_input( 'cs_bar_verified_link' ); ?>
                    </div>

                    <div class="col-10">
                        <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Add a "Verified by ConsentMagic" link on the consent message', 'consent-magic' ); ?></h3>
                    </div>
                </div>

                <div class="row" style="margin-bottom: 15px;">
                    <div class="col-1">
						<?php echo render_switcher_input( 'cs_options_verified_link' ); ?>
                    </div>

                    <div class="col-10">
                        <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Add a "Verified by ConsentMagic" link on the options popup', 'consent-magic' ); ?></h3>
                    </div>
                </div>
                <div class="row">
                    <div class="col-1">
						<?php echo render_switcher_input( 'cs_options_single_verified_link' ); ?>
                    </div>

                    <div class="col-10">
                        <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Add a "Verified by ConsentMagic" link on single-step template', 'consent-magic' ); ?></h3>
                    </div>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col-1">
					<?php echo render_switcher_input( 'cs_send_important' ); ?>
                </div>

                <div class="col-10">
                    <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Send important emails', 'consent-magic' ); ?></h3>
					<?php render_multi_select_input( 'cs_send_important_emails', get_option( 'cs_send_important_emails' ), false, 'cs_multi_select_tags' ); ?>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col-12">
                    <h3 class="label"><?php esc_html_e( 'Permissions:', 'consent-magic' ); ?></h3>
                    <h4 style="margin: 35px 0 13px;"><?php esc_html_e( "Select user's role:", "consent-magic" ); ?></h4>
					<?php render_multi_select_input( 'cs_admin_permissions', getAvailableUserRoles(), false, 'cs_multi_select' ); ?>
                </div>

                <div class="col-12" style="margin-top: 10px;">
                    <p><?php esc_html_e( 'Administrators are always allowed.', 'consent-magic' ); ?></p>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col-12">
                    <h3 class="label"><?php esc_html_e( 'Ignore these user roles:', 'consent-magic' ); ?></h3>
                    <h4 style="margin: 35px 0 13px;"><?php esc_html_e( "Select user's role:", "consent-magic" ); ?></h4>
					<?php render_multi_select_input( 'cs_admin_ignore_users', getAvailableUserRoles(), false, 'cs_multi_select', null, true ); ?>
                </div>

                <div class="col-12" style="margin-top: 10px;">
                    <p><?php esc_html_e( 'Selected roles are ignored, and these users will not see any consent messages when browsing the website.', 'consent-magic' ); ?></p>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col-12">
                    <h3 class="label"><?php esc_html_e( 'Ignore these user IP:', 'consent-magic' ); ?></h3>
                    <div class="row align-items-center">
                        <div class="col-8">
                            <input type="text" name="new_ignore_ip"
                                   id="new_ignore_ip"
                                   class="new_ignore_ip" value="" style="width: 100%;"/>
                            <div class="error-message cs-error-message"
                                 style="display: none; margin-top: 15px;"></div>
                        </div>

                        <div class="col">
                            <button type="button" id="add_new_ignore_ip" class="btn btn-blue"
                                    style="margin: 0 0 0 auto;display: block;"><i
                                        class="icon-plus"></i><?php esc_html_e( 'Add new IP', "consent-magic" ); ?>
                            </button>
                        </div>
                    </div>

                    <h4 style="margin: 35px 0 13px;"><?php esc_html_e( "User's IP list:", "consent-magic" ); ?></h4>
                    <div class="well">
                        <h4><?php esc_html_e( 'Date range filters', "consent-magic" ); ?></h4>
                    </div>

                    <table style="width:100%;margin-bottom: 25px;">
                        <tr>
                            <td>
                                <div class="datepicker_ip"
                                     style="background: #fff; cursor: pointer; padding: 5px 10px; border: 1px solid #ccc; width: 100%">
                                    <i class="fa fa-calendar"></i>&nbsp;
                                    <span></span> <i class="fa fa-caret-down"></i>
                                </div>
                            </td>
                            <td>
                                <button type="button" id="btn_search_ip" class="btn btn-blue"
                                        style="margin: 0 0 0 auto;display: block;"><i
                                            class="icon-browse"></i><?php esc_html_e( 'Search', "consent-magic" ); ?>
                                </button>
                            </td>
                        </tr>
                    </table>

                    <table id="ignore_ip_table" class="display" style="width:100%;">
                        <thead>
                        <tr>
                            <th></th>
                            <th><?php esc_html_e( 'IP', "consent-magic" ); ?></th>
                            <th><?php esc_html_e( 'Time', "consent-magic" ); ?></th>
                        </tr>
                        </thead>
                        <tfoot>
                        <tr>
                            <th></th>
                            <th><?php esc_html_e( 'IP', "consent-magic" ); ?></th>
                            <th><?php esc_html_e( 'Time', "consent-magic" ); ?></th>
                        </tr>
                        </tfoot>
                    </table>
                </div>
                <div class="col-12" style="margin-top: 10px;">
                    <p><?php esc_html_e( 'IP in this list are ignored, and these users will not see any consent messages when browsing the website.', 'consent-magic' ); ?></p>
                </div>

                <div class="col" style="margin-top: 20px;">
                    <div class="row">
                        <div class="col-1">
							<?php echo render_switcher_input( 'cs_disable_for_knonw_crawlers' ); ?>
                        </div>

                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Disable the plugin for known crawlers', 'consent-magic' ); ?></h3>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col">
                    <div class="row">
                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Renew Consent', 'consent-magic' ); ?></h3>
                            <p><?php esc_html_e( 'This will "invalidate" all expressed consent, asking every visitor for consent again.', 'consent-magic' ); ?></p>
                        </div>
                    </div>
                </div>

                <div class="col-3">
                    <button type="button" class="btn btn-blue cs_renew_consent_confirm"><i
                                class="icon-renew"></i> <?php esc_html_e( 'Renew Consent', 'consent-magic' ); ?>
                    </button>
                </div>
            </div>
        </div>

        <div class="rules-wrap-border">
            <div class="row rules-wrap">
                <div class="col-8">
                    <div class="row">
                        <div class="col-10">
                            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Restart Setup Process', 'consent-magic' ); ?></h3>
                            <p><?php esc_html_e( ' This option will restart the setup flow, and reset all settings to default.', 'consent-magic' ); ?></p>
                        </div>
                    </div>
                </div>

                <div class="col-4">
                    <button type="button" class="btn btn-blue cs_restart_setup"><i
                                class="icon-renew"></i> <?php esc_html_e( 'Restart Setup Process', 'consent-magic' ); ?>
                    </button>
                </div>
            </div>
        </div>

        <div class="card rules-wrap-no-border">
            <div class="card-header">
                <div class="row">
                    <div class="col">
                        <h3 class="card_title"><?php esc_html_e( 'Export/Import settings', 'consent-magic' ); ?></h3>
                    </div>

                    <div class="col-2 right-aligned">
                        <button type="button" class="btn btn-link card-collapse">
							<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                    class="icon-down"></i>
                        </button>
                    </div>
                </div>
            </div>

            <div class="card-body" style="display: none;">
                <div class="cart_line_item input_row_default">
                    <p><?php esc_html_e( 'Select the settings to export:', 'consent-magic' ); ?></p>

                    <div class="row input_row cs_data_render">
                        <div id="cs_export_settings" class="mb-20">
							<?php
							echo render_subcheckbox_input( 'cs_all_settings', true, false, null, false, false, 'All settings' );
							echo render_subcheckbox_input( 'cs_general_settings', true, false, null, false, false, 'General settings' );
							//(including all settings, blocking settings, consent proof storing, scanner settings)
							echo render_subcheckbox_input( 'cs_iab_settings', true, false, null, false, false, 'IAB settings' );
							echo render_subcheckbox_input( 'cs_geolocation_settings', true, false, null, false, false, 'Geolocation settings' );
							echo render_subcheckbox_input( 'cs_default_rules', true, false, null, false, false, 'Default rules' );
							echo render_subcheckbox_input( 'cs_custom_rules', true, false, null, false, false, 'Custom rules' );
							echo render_subcheckbox_input( 'cs_predefined_scripts', true, false, null, false, false, 'Pre-defined scripts' );
							echo render_subcheckbox_input( 'cs_custom_scripts', true, false, null, false, false, 'Custom scripts' );
							echo render_subcheckbox_input( 'cs_design_settings', true, false, null, false, false, 'Design templates and settings' );
							echo render_subcheckbox_input( 'cs_script_types', true, false, null, false, false, 'Cookie/Script types with translations' );
							echo render_subcheckbox_input( 'cs_text', true, false, null, false, false, 'Text with translations' );
							?>
                        </div>

                        <div class="d-flex justify-content-around">
							<?php include_once CMPRO_PLUGIN_VIEWS_PATH . "admin/buttons/admin-settings-export-settings-button.php"; ?>
							<?php include_once CMPRO_PLUGIN_VIEWS_PATH . "admin/buttons/admin-settings-import-settings-button.php"; ?>
                        </div>

                        <div class="cs_settings_message mr-20 mt-10"></div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="cs_preview_container cs_renew_consent_wrap" style="display: none;">
        <div class="cs-info-bar cs-public-cookie-popup popup_small"
             style="box-shadow: rgba(0,0,0,0.5) 0 2px 10px;text-align: center;">
            <div class="cs-modal cs-blowup">
                <div class="cs-modal-dialog" role="document">
                    <div class="cs-modal-content cs-bar-popup">
                        <div class="cs-container-fluid cs-tab-container">
                            <p><?php esc_html_e( 'Are you sure you want to renew consent?', 'consent-magic' ); ?></p>
                            <button type="button" class="btn btn-blue cs_renew_consent"><i
                                        class="icon-renew"></i> <?php esc_html_e( 'Yes Renew Consent', 'consent-magic' ); ?>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="cs_preview_container cs_deactivation_db_clear_popup" style="display: none;">
        <div class="cs-info-bar cs-public-cookie-popup popup_small"
             style="box-shadow: rgba(0,0,0,0.5) 0 2px 10px;text-align: center;">
            <div class="cs-modal cs-blowup">
                <div class="cs-modal-dialog" role="document">
                    <div class="cs-modal-content cs-bar-popup">
                        <div class="cs-container-fluid cs-tab-container">
                            <p><?php esc_html_e( 'Caution: if you enable this option, all the data will be deleted when the plugin is deactivated', 'consent-magic' ); ?></p>
                            <button type="submit" name="update_admin_settings_form"
                                    class="btn btn-blue btn-right"
                                    onClick="return cs_store_settings_btn_click(this.name)">
                                <i class="icon-renew"></i> <?php esc_html_e( 'Confirm', 'consent-magic' ); ?>
                            </button>
                            <button type="button"
                                    class="btn btn-blue btn-right cs_deactivation_db_clear_close">
								<?php esc_html_e( 'Close', 'consent-magic' ); ?>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="cs_preview_container cs_restart_setup_wrap" style="display: none;">
        <div class="cs-info-bar cs-public-cookie-popup popup_small"
             style="box-shadow: rgba(0,0,0,0.5) 0 2px 10px;text-align: center;">
            <div class="cs-modal cs-blowup">
                <div class="cs-modal-dialog" role="document">
                    <div class="cs-modal-content cs-bar-popup">
                        <div class="cs-container-fluid cs-tab-container">
                            <p>
								<?php
								if ( ConsentMagic()->getOption( 'cs_deactivation_db_clear' ) == 1 ) {
									echo esc_html__( 'Warning!', 'consent-magic' ) . '<br>' . esc_html__( 'You enabled option "Remove all data when deactivating the plugin". With this option all settings and user data will reset to default. Are you sure you want to restart the setup flow?', 'consent-magic' );
								} else {
									esc_html_e( 'Are you sure to restart the setup flow, and reset all predefined settings to default? User settings and data will not be affected.', 'consent-magic' );
								}
								?>
                            </p>
                            <button type="submit" name="restart_setup_process"
                                    class="btn btn-blue btn-right cs_restart_setup_close"
                                    onClick="return cs_store_settings_btn_click(this.name)">
                                <i class="icon-renew"></i> <?php esc_html_e( 'Confirm', 'consent-magic' ); ?>
                            </button>
                            <button type="button"
                                    class="btn btn-blue btn-right cs_restart_setup_close">
								<?php esc_html_e( 'Close', 'consent-magic' ); ?>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="cs_preview_container cs_restore_translations_wrap"
         style="display: none; <?php echo ( isset( $settings_page ) ) ? 'position:absolute;' : '' ?>">
        <div class="cs-info-bar cs-public-cookie-popup popup_small"
             style="box-shadow: rgba(0,0,0,0.5) 0 2px 10px;text-align: center;">
            <div class="cs-modal cs-blowup">
                <div class="cs-modal-dialog" role="document">
                    <div class="cs-modal-content cs-bar-popup">
                        <div class="cs-container-fluid cs-tab-container">
                            <p><?php esc_html_e( 'This will restore the default translations for all front-end text, and default categories. Custom text translations and extra categories translations will not be affected.', 'consent-magic' ); ?></p>
                            <button type="button" class="btn btn-blue btn-right restore_translations_close">
								<?php esc_html_e( 'Cancel', 'consent-magic' ); ?>
                            </button>
                            <button type="submit" style="margin-bottom: 20px;" name="cs_restore_translations"
                                    class="btn btn-blue btn-right restore_translations_close"
                                    onClick="return cs_store_settings_btn_click(this.name)">
                                <i class="icon-delete"></i> <?php esc_html_e( 'Delete and Restore', 'consent-magic' ); ?>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="container container-clear container-footer">
		<?php
		//save button
		include CMPRO_PLUGIN_VIEWS_PATH . "admin/buttons/admin-settings-save-button.php";
		?>
    </div>
</div>